@@ -15,10 +15,10 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-#
+"""This module contains Azure Data Explorer operators."""
+from __future__ import annotations
 
-"""This module contains Azure Data Explorer operators"""
-from typing import TYPE_CHECKING, Optional, Sequence, Union
+from typing import TYPE_CHECKING, Sequence
 
 from azure.kusto.data._models import KustoResultTable
 
@@ -35,28 +35,24 @@ class AzureDataExplorerQueryOperator(BaseOperator):
     Operator for querying Azure Data Explorer (Kusto).
 
     :param query: KQL query to run (templated).
-    :type query: str
     :param database: Database to run the query on (templated).
-    :type database: str
     :param options: Optional query options. See:
       https://docs.microsoft.com/en-us/azure/kusto/api/netfx/request-properties#list-of-clientrequestproperties
-    :type options: dict
     :param azure_data_explorer_conn_id: Reference to the
         :ref:`Azure Data Explorer connection<howto/connection:adx>`.
-    :type azure_data_explorer_conn_id: str
     """
 
-    ui_color = '#00a1f2'
-    template_fields: Sequence[str] = ('query', 'database')
-    template_ext: Sequence[str] = ('.kql',)
+    ui_color = "#00a1f2"
+    template_fields: Sequence[str] = ("query", "database")
+    template_ext: Sequence[str] = (".kql",)
 
     def __init__(
         self,
         *,
         query: str,
         database: str,
-        options: Optional[dict] = None,
-        azure_data_explorer_conn_id: str = 'azure_data_explorer_default',
+        options: dict | None = None,
+        azure_data_explorer_conn_id: str = "azure_data_explorer_default",
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -66,18 +62,20 @@ class AzureDataExplorerQueryOperator(BaseOperator):
         self.azure_data_explorer_conn_id = azure_data_explorer_conn_id
 
     def get_hook(self) -> AzureDataExplorerHook:
-        """Returns new instance of AzureDataExplorerHook"""
+        """Returns new instance of AzureDataExplorerHook."""
         return AzureDataExplorerHook(self.azure_data_explorer_conn_id)
 
-    def execute(self, context: "Context") -> Union[KustoResultTable, str]:
+    def execute(self, context: Context) -> KustoResultTable | str:
         """
         Run KQL Query on Azure Data Explorer (Kusto).
-        Returns `PrimaryResult` of Query v2 HTTP response contents
-        (https://docs.microsoft.com/en-us/azure/kusto/api/rest/response2)
+
+        Returns `PrimaryResult` of Query v2 HTTP response contents.
+
+        https://docs.microsoft.com/en-us/azure/kusto/api/rest/response2
         """
         hook = self.get_hook()
         response = hook.run_query(self.query, self.database, self.options)
-        if conf.getboolean('core', 'enable_xcom_pickling'):
+        if conf.getboolean("core", "enable_xcom_pickling"):
             return response.primary_results[0]
         else:
             return str(response.primary_results[0])
